SNOMEDconcept is an S3 class for vectors of SNOMED concept IDs as 64-bit integers. This function checks whether the object has the class SNOMEDconcept and is a vector of 64-bit integers.
# S3 method for SNOMEDconcept
print(x, ...)invisibly returns a character vector of the SNOMED CT concepts with descriptions separated by pipe (|)
SNOMEDconcept object, or something that can be coerced to one
not required
Other SNOMEDconcept functions:
as.data.frame.SNOMEDconcept(),
c.SNOMEDconcept(),
is.SNOMEDconcept(),
union.SNOMEDconcept(),
unique.SNOMEDconcept()